# Xenopict

Xenopict is a package for generating publication quality 2D depictions of small molecules, 
with special attention to "shading" molecules with atom or bond level properties. This package
relies on RDKit generation an initial SVG depiction of the input molecule.

Read the [documentation](https://swamidasslab.github.io/xenopict) for more information.

